Module: Coatepec

Defined in:
lib/coatepec.rb,
lib/coatepec/cli.rb,
lib/coatepec/mcp.rb,
lib/coatepec/errors.rb,
lib/coatepec/project.rb,
lib/coatepec/version.rb,
lib/coatepec/protocol.rb,
lib/coatepec/mcp/tools.rb,
lib/coatepec/spec/result.rb,
lib/coatepec/spec/runner.rb,
lib/coatepec/mcp/response.rb,
lib/coatepec/worker/client.rb,
lib/coatepec/worker/server.rb,
lib/coatepec/project_config.rb,
lib/coatepec/worker_manager.rb,
lib/coatepec/spec/path_policy.rb,
lib/coatepec/spec/fork_strategy.rb,
lib/coatepec/introspection/model.rb,
lib/coatepec/spec/spawn_strategy.rb,
lib/coatepec/introspection/routes.rb,
lib/coatepec/worker/rails_runtime.rb,
lib/coatepec/spec/process_strategy.rb,
lib/coatepec/worker/change_detector.rb,
lib/coatepec/introspection/safe_options.rb,
lib/coatepec/spec/guarded_fork_strategy.rb,
sig/coatepec.rbs

Overview

Coatepec is a local stdio MCP sidecar that keeps an isolated Rails test worker warm so coding agents can run targeted RSpec examples quickly, without exposing a general Rails console.

Defined Under Namespace

Modules: Introspection, MCP, Spec, Worker Classes: CLI, Error, Project, ProjectConfig, Protocol, WorkerManager

Constant Summary collapse

VERSION =

Returns:

  • (String)
"0.4.0"